Module: Bunko::Models::PostMethods::Publishable
- Extended by:
- ActiveSupport::Concern
- Included in:
- Bunko::Models::PostMethods
- Defined in:
- lib/bunko/models/post_methods/publishable.rb
Instance Method Summary collapse
-
#scheduled? ⇒ Boolean
Instance method to check if post is scheduled for future publication.
Instance Method Details
#scheduled? ⇒ Boolean
Instance method to check if post is scheduled for future publication
27 28 29 |
# File 'lib/bunko/models/post_methods/publishable.rb', line 27 def scheduled? status == "published" && published_at.present? && published_at > Time.current end |